player = {}
water = {}
block = {}
world = {}

local gravity = 1800
local run = 320
local jumpv = -900
local floor = 500

function love.load()
	--textures
	player_img = love.graphics.newImage("textures/player.png")
	water_img = love.graphics.newImage("textures/water.png")
	block_img = love.graphics.newImage("textures/block.png")
	
	
	--player
	player.x = 350
	player.y = 50
	player.w = 50
	player.h = 50
	player.dir = "left"
	player.xvel = 0
	player.yvel = 0
	player.canJump = true		
	
	
	world:load()
end

function love.update(dt)
	
	x, y = love.mouse.getPosition()
	if love.mouse.isDown("l") then
		table.insert(block, {x = x, y = y})
	end
	
	--controls
	if love.keyboard.isDown("right") or love.keyboard.isDown("d") then  
		
		for i, v in pairs(block) do
			block[i].x = block[i].x - run*dt
		end
		
		for i, v in pairs(water) do
			water[i].x = water[i].x - run*dt
		end
		
		--player.x = player.x + run * dt 
		
		player.dir = "right"
		
	end
	
	if love.keyboard.isDown("left") or love.keyboard.isDown("a") then  
		
		for i, v in pairs(block) do
			block[i].x = block[i].x + run*dt
		end
		
		for i, v in pairs(water) do
			water[i].x = water[i].x + run*dt
		end
		
		--player.x = player.x - run * dt
		
		player.dir = "left"
	end
	
	
	--gravity
	player.y = player.y + ( player.yvel * dt)
	player.yvel = player.yvel + ( gravity * dt)
	
	
	--stop falling
	if player.y >= floor - player.h then
		player.y = floor - player.h; player.yvel= 0;
		player.canJump = true
    end
	
	
	--block hit boxes
	for i, v in pairs(block) do
		if CheckCollision(player.x, player.y+50, 50, 1, block[i].x, block[i].y, 50, 1) then
			player.y = block[i].y - player.h; player.yvel = 0;
			player.canJump = true
		end
	end

	
	--move water drops
	for i, v in pairs(water) do
		if water[i].dir == "left" then
			water[i].x = water[i].x - 350*dt
		elseif water[i].dir == "right" then
			water[i].x = water[i].x + 350*dt
		end
	end
	
		
end

function love.draw()	
	
	--draw the blocks
	love.graphics.setColor(255, 255, 255, 255)
	for i, v in pairs(block) do 
		love.graphics.draw(block_img, block[i].x, block[i].y)
	end
	
	--player
	love.graphics.setColor(255, 130, 130, 255)
	love.graphics.draw(player_img, player.x, player.y)	
	
	--draw the water droplets
	love.graphics.setColor(255, 130, 130, 255)
	for i, v in pairs(water) do 
		love.graphics.draw(water_img, water[i].x, water[i].y)
	end
	
	love.graphics.setColor(64, 0, 128, 255)
	love.graphics.rectangle("fill", player.x, player.y+50, 50, 1)
	for i, v in pairs(block) do 
		love.graphics.rectangle("fill", block[i].x, block[i].y, 50, 1)
	end
	
end

function love.keypressed( key, unicode )
		--jump
		if key == " " and player.canJump then
			 player.yvel = jumpv
			 player.canJump = false
		end
		
		--spawn the water
		if key == "z" then
			table.insert(water, {x = player.x, y = player.y, dir = player.dir})
		end
end

function world:load()
	table.insert(block, {x = 0, y = 50})
	table.insert(block, {x = 50, y = 50})
	table.insert(block, {x = 150, y = 200})
	table.insert(block, {x = 300, y = 450})
	table.insert(block, {x = 250, y = 400})
	for i=1,7 do
		table.insert(block, {x = 150+i*50, y = 200})
		table.insert(block, {x = 250+i*50, y = 450})
	end
end

function CheckCollision(x1,y1,w1,h1, x2,y2,w2,h2)
	return x1 < x2+w2 and
		x2 < x1+w1 and
		y1 < y2+h2 and
		y2 < y1+h1
end